@@ -1,9 +1,9 @@
 """
-@Author: dongyu
-@Date: 2020-04-11 18:44:08
-@LastEditTime: 2020-12-09 15:46:02
-@LastEditors: ChenXiaolei
-@Description: 菜单相关类
+:Author: dongyu
+:Date: 2020-04-11 18:44:08
+:LastEditTime: 2020-12-09 15:46:02
+:LastEditors: ChenXiaolei
+:Description: 菜单相关类
 """
 from seven_studio.handlers.studio_base import *
 from seven_studio.models.db_models.menu.menu_cote_model import *
@@ -13,16 +13,16 @@ from seven_studio.models.power_model import *
 
 class PowerPlatformMenuHandler(StudioBaseHandler):
     """
-    @description: 权限的栏目菜单路由
+    :description: 权限的栏目菜单路由
     """
     @login_filter(True)
     @power_filter(False)
     def get_async(self):
         """
-        @description: 根据登陆用户获取用户有权限的栏目菜单
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 根据登陆用户获取用户有权限的栏目菜单
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         is_super = self.get_is_super()
@@ -37,16 +37,16 @@ class PowerPlatformMenuHandler(StudioBaseHandler):
 
 class PowerMenuTreeHandler(StudioBaseHandler):
     """
-    @description: 菜单权限路由
+    :description: 菜单权限路由
     """
     @login_filter(True)
     @power_filter(False)
     def get_async(self):
         """
-        @description: 获取权限树
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取权限树
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         is_super = self.get_is_super()
@@ -61,14 +61,14 @@ class PowerMenuTreeHandler(StudioBaseHandler):
 
 class MenuTreeHandler(StudioBaseHandler):
     """
-    @description: 系统菜单路由
+    :description: 系统菜单路由
     """
     @login_filter(True)
     def get_async(self):
         """
-        @description: 获取系统菜单树
-        @param {type} 
-        @return: 列表
+        :description: 获取系统菜单树
+        :param {type} 
+        :return: 列表
         """
         manage_context_key = self.get_manage_context_key()
         curr_user_id = self.request_user_id()
@@ -82,14 +82,14 @@ class MenuTreeHandler(StudioBaseHandler):
 
 class MenuPowerInfoHandler(StudioBaseHandler):
     """
-    @description: 栏目权限路由
+    :description: 栏目权限路由
     """
     def get_async(self):
         """
-        @description: 栏目权限信息路由，用于获取栏目的角色和用户信息
-        @param {type} 
-        @return: 列表
-        @last_editors: HuangJingCan
+        :description: 栏目权限信息路由，用于获取栏目的角色和用户信息
+        :param {type} 
+        :return: 列表
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.get_manage_context_key()
         is_super = self.get_is_super()
@@ -104,14 +104,14 @@ class MenuPowerInfoHandler(StudioBaseHandler):
 
 class MenuCoteListHandler(StudioBaseHandler):
     """
-    @description: 栏目数据路由
+    :description: 栏目数据路由
     """
     def post_async(self):
         """
-        @description: 获取栏目数据列表
-        @param {type} 
-        @return: 列表
-        @last_editors: HuangJingCan
+        :description: 获取栏目数据列表
+        :param {type} 
+        :return: 列表
+        :last_editors: HuangJingCan
         """
         page_index = self.get_page_index()
         page_size = self.get_page_size()
@@ -124,14 +124,14 @@ class MenuCoteListHandler(StudioBaseHandler):
 
 class MenuCoteSelectHandler(StudioBaseHandler):
     """
-    @description: MenuCoteSelectHandler
+    :description: MenuCoteSelectHandler
     """
     def get_async(self):
         """
-        @description: GetMenuCoteSelect
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: GetMenuCoteSelect
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         p_dict = MenuCoteModel(self.get_manage_context_key()).get_dict_list(field="MenuCoteID,CoteTitle")
 
@@ -140,14 +140,14 @@ class MenuCoteSelectHandler(StudioBaseHandler):
 
 class SaveMenuHandler(StudioBaseHandler):
     """
-    @description: 保存菜单
+    :description: 保存菜单
     """
     def post_async(self):
         """
-        @description: 保存菜单
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存菜单
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         parent_id = self.get_param("parentID")
@@ -215,16 +215,16 @@ class SaveMenuHandler(StudioBaseHandler):
 
 class AddFastMenuHandler(StudioBaseHandler):
     """
-    @description: 快速添加菜单
+    :description: 快速添加菜单
     """
     def get_async(self):
         """
-        @description: 快速添加菜单-保存
-        @param parent_id
-        @param button_type_str
-        @param suffix_name
-        @return: 菜单id
-        @last_editors: HuangJingCan
+        :description: 快速添加菜单-保存
+        :param parent_id
+        :param button_type_str
+        :param suffix_name
+        :return: 菜单id
+        :last_editors: HuangJingCan
         """
         parent_id = self.get_param("parentID", "")
         button_type_str = self.get_param("buttonTypeStr", "")
@@ -242,14 +242,14 @@ class AddFastMenuHandler(StudioBaseHandler):
 
 class DeleteMenuHandler(StudioBaseHandler):
     """
-    @description: 删除菜单
+    :description: 删除菜单
     """
     def get_async(self):
         """
-        @description: 删除菜单
-        @param id：菜单id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除菜单
+        :param id：菜单id
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_id = self.get_param("id", "")
         if menu_id == "":
@@ -262,15 +262,15 @@ class DeleteMenuHandler(StudioBaseHandler):
 
 class SaveCopyMenuHandler(StudioBaseHandler):
     """
-    @description: 复制粘贴菜单
+    :description: 复制粘贴菜单
     """
     def get_async(self):
         """
-        @description: 复制粘贴菜单
-        @param copyMenuID：复制的菜单id
-        @param stickMenuID：粘贴的菜单id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 复制粘贴菜单
+        :param copyMenuID：复制的菜单id
+        :param stickMenuID：粘贴的菜单id
+        :return: 
+        :last_editors: HuangJingCan
         """
         copy_menu_id = self.get_param("copyMenuID", "")
         stick_menu_id = self.get_param("stickMenuID", "")
@@ -286,16 +286,16 @@ class SaveCopyMenuHandler(StudioBaseHandler):
 
 class MoveMenuHandler(StudioBaseHandler):
     """
-    @description: 移动菜单
+    :description: 移动菜单
     """
     def get_async(self):
         """
-        @description: 移动菜单
-        @param id：被移动的菜单id
-        @param targetId：目的地菜单id
-        @param moveType：移动类型
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 移动菜单
+        :param id：被移动的菜单id
+        :param targetId：目的地菜单id
+        :param moveType：移动类型
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_id = self.get_param("id", "")
         if menu_id == "":
@@ -326,14 +326,14 @@ class MoveMenuHandler(StudioBaseHandler):
 
 class SaveMenuCoteHandler(StudioBaseHandler):
     """
-    @description: 修改栏目数据
+    :description: 修改栏目数据
     """
     def post_async(self):
         """
-        @description: 保存栏目数据
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 保存栏目数据
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         # 获取参数
         menu_cote_id = self.get_param("MenuCoteID", "0")
@@ -383,14 +383,14 @@ class SaveMenuCoteHandler(StudioBaseHandler):
 
 class DeleteMenuCoteHandler(StudioBaseHandler):
     """
-    @description: 删除栏目数据
+    :description: 删除栏目数据
     """
     def get_async(self):
         """
-        @description: 删除栏目数据
-        @param id：栏目数据id
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除栏目数据
+        :param id：栏目数据id
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_cote_id = self.get_param("MenuCoteID")
         if menu_cote_id == "":
@@ -403,14 +403,14 @@ class DeleteMenuCoteHandler(StudioBaseHandler):
 
 class SyncSqlHandler(StudioBaseHandler):
     """
-    @description: sql同步语句导出
+    :description: sql同步语句导出
     """
     def get_async(self):
         """
-        @description: 
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_id = self.get_param("menuID")
         if menu_id == "":
@@ -427,14 +427,14 @@ class SyncSqlHandler(StudioBaseHandler):
 
 class InsertSqlHandler(StudioBaseHandler):
     """
-    @description: sql插入语句导出
+    :description: sql插入语句导出
     """
     def get_async(self):
         """
-        @description: 
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_id = self.get_param("menuID")
         if menu_id == "":
@@ -451,14 +451,14 @@ class InsertSqlHandler(StudioBaseHandler):
 
 class UpdateSqlHandler(StudioBaseHandler):
     """
-    @description: sql更新语句导出
+    :description: sql更新语句导出
     """
     def get_async(self):
         """
-        @description: 
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_id = self.get_param("menuID")
         if menu_id == "":
