@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-29 11:00:52
-:LastEditTime: 2020-12-15 18:25:44
+:LastEditTime: 2021-01-06 15:36:02
 :LastEditors: ChenXiaolei
 :Description: 文件上传信息
 """
@@ -10,6 +10,7 @@ from PIL import Image
 from io import BytesIO
 from seven_studio.libs.file.ks3 import *
 from seven_studio.libs.file.oss2 import *
+from seven_studio.libs.file.cos import *
 from seven_studio.utils.random import *
 from seven_framework.time import *
 from seven_framework.uuid import *
@@ -242,6 +243,24 @@ class FileUpload():
                 file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
                 file_upload_info.ImageHeight = invoke_result.Data[
                     "ImageHeight"]
+        elif file_storage_path.StorageTypeID == 6:
+            # 腾讯云
+            invoke_result = COS.upload(file_storage_path.StorageConfig,
+                                           file_name, stream)
+
+            if invoke_result.ResultCode != "0":
+                return invoke_result
+
+            if invoke_result.Data:
+                file_upload_info.Md5Value = invoke_result.Data["Md5Value"]
+                file_upload_info.ResourcePath = invoke_result.Data[
+                    "ResourcePath"]
+                file_upload_info.OriginalName = invoke_result.Data[
+                    "OriginalName"]
+                file_upload_info.FilePath = invoke_result.Data["FilePath"]
+                file_upload_info.ImageWidth = invoke_result.Data["ImageWidth"]
+                file_upload_info.ImageHeight = invoke_result.Data[
+                    "ImageHeight"]
 
         if file_restrict.IsHistory == 1:
             file_history = FileHistory()
