@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-12-09 19:10:46
-@LastEditTime: 2020-12-10 11:08:48
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: ChenXiaolei
+:Date: 2020-12-09 19:10:46
+:LastEditTime: 2020-12-10 11:08:48
+:LastEditors: ChenXiaolei
+:Description: 
 """
 __all__=["file_restrict_model","file_water_image_model","file_storage_path_model","file_history_model","file_resource_model","file_restrict_pic_model",]
\ No newline at end of file
