@@ -1,9 +1,9 @@
 """
-@Author: HuangJingCan
-@Date: 2020-04-15 09:56:24
-@LastEditTime: 2020-12-10 17:19:53
-@LastEditors: ChenXiaolei
-@Description: 权限角色栏目相关
+:Author: HuangJingCan
+:Date: 2020-04-15 09:56:24
+:LastEditTime: 2020-12-10 17:19:53
+:LastEditors: ChenXiaolei
+:Description: 权限角色栏目相关
 """
 
 from seven_studio.utils.dict import *
@@ -22,7 +22,7 @@ from seven_studio.models.dto_model import *
 
 class PowerModel():
     """
-    @description: 权限相关操作类
+    :description: 权限相关操作类
     """
     def __init__(self, db_connect_key='db_sevenstudio', is_super=False, user_id="", product_id=0):
         self.db = MySQLHelper(config.get_value(db_connect_key))
@@ -35,10 +35,10 @@ class PowerModel():
 
     def get_power_menu_list(self):
         """
-        @description: 获取栏目列表
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取栏目列表
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         manage_context_key = self.db_connect_key
         menu_info_list = []
@@ -59,10 +59,10 @@ class PowerModel():
 
     def get_platform_power_menu_list(self):
         """
-        @description: 获取权限菜单
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取权限菜单
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_info_list = self.get_power_menu_list()
         menu_item_list = []
@@ -269,10 +269,10 @@ class PowerModel():
 
     def get_menu_item_tree(self, is_load_cote_menu=True):
         """
-        @description: 获取栏目树
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 获取栏目树
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         menu_info_list = self.get_power_menu_list()
         menu_item_list = []
@@ -389,10 +389,10 @@ class PowerModel():
 
     def get_power_menu_role_list(self, menu_id):
         """
-        @description: 根据栏目id获取角色和用户
-        @param menu_id：栏目id
-        @return: 角色用户列表
-        @last_editors: HuangJingCan
+        :description: 根据栏目id获取角色和用户
+        :param menu_id：栏目id
+        :return: 角色用户列表
+        :last_editors: HuangJingCan
         """
         menu_role_list = []
         rowle_power_list = RolePowerModelEx(self.db_connect_key).get_list("MenuID=%s", params=menu_id)
@@ -415,10 +415,10 @@ class PowerModel():
 
     def remove_role_user(self, role_id, user_id):
         """
-        @description: 删除用户角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 删除用户角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         role_user_model = RoleUserModel(self.db_connect_key)
         if self.is_super:
@@ -430,10 +430,10 @@ class PowerModel():
 
     def set_role(self, role_info, user_id_list, menu_id_list, is_add=False):
         """
-        @description: 设置角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 设置角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         role_info_model = RoleInfoModel(self.db_connect_key)
         user_id_list = [i for i in user_id_list if i != ""]
@@ -491,10 +491,10 @@ class PowerModel():
 
     def set_user(self, user_info, role_id_list, product_id_list, password, change_pw=False, is_add=False):
         """
-        @description: 
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         user_info_model = UserInfoModel(self.db_connect_key)
         base_user_info_model = UserInfoModel(config.get_value("base_manage_context_key"))
@@ -539,10 +539,10 @@ class PowerModel():
 
     def add_user_role(self, user_id, role_id_list):
         """
-        @description: 添加用户角色
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 添加用户角色
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         role_user_model = RoleUserModel(self.db_connect_key)
         role_user_model.del_entity("UserID=%s", user_id)
@@ -559,10 +559,10 @@ class PowerModel():
 
     def add_product_user(self, user_id, product_id_list):
         """
-        @description: 添加产品用户
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 添加产品用户
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         product_user_model = ProductUserModel(config.get_value("base_manage_context_key"))
         product_user_model.del_entity("UserID=%s", user_id)
@@ -577,10 +577,10 @@ class PowerModel():
 
     def set_base_user(self, user_info):
         """
-        @description: 子产品将用户同步回主库之中
-        @param {type} 
-        @return: 
-        @last_editors: HuangJingCan
+        :description: 子产品将用户同步回主库之中
+        :param {type} 
+        :return: 
+        :last_editors: HuangJingCan
         """
         if self.product_id > 0:
             base_user_info_model = UserInfoModel(config.get_value("base_manage_context_key"), "")
@@ -599,11 +599,11 @@ class PowerModel():
 
     def export_sql(self, menu_id, mode=3):
         """
-        @description: 导出sql语句
-        @param menu_id：栏目id
-        @param mode：模式类型（1-新增，2-更新，3-同步）
-        @return: str
-        @last_editors: HuangJingCan
+        :description: 导出sql语句
+        :param menu_id：栏目id
+        :param mode：模式类型（1-新增，2-更新，3-同步）
+        :return: str
+        :last_editors: HuangJingCan
         """
         sql = ""
         menu_info_model = MenuInfoModel(self.db_connect_key)
@@ -622,10 +622,10 @@ class PowerModel():
 
     def remove_user(self, curr_user_id, user_id):
         """
-        @description: 删除用户
-        @param {*}
-        @return {*}
-        @last_editors: HuangJingCan
+        :description: 删除用户
+        :param {*}
+        :return {*}
+        :last_editors: HuangJingCan
         """
         user_info_model = UserInfoModel(self.db_connect_key)
 
@@ -638,10 +638,10 @@ class PowerModel():
 
     def copy_user_role(self, copy_user_id, user_id):
         """
-        @description: 复制权限
-        @param {*}
-        @return {*}
-        @last_editors: HuangJingCan
+        :description: 复制权限
+        :param {*}
+        :return {*}
+        :last_editors: HuangJingCan
         """
         role_id_list = RoleUserModel(self.db_connect_key).get_list("UserID=%s", params=copy_user_id)
         role_id_list = [i.RoleID for i in role_id_list if i != ""]
